
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.009.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "Mojolicious Plugin for CSS theming",
  "dist_author" => [
    "Kathryn Andersen <perlkat\@katspace.org>"
  ],
  "dist_name" => "Mojolicious-Plugin-Foil",
  "dist_version" => "0.005",
  "license" => "perl",
  "module_name" => "Mojolicious::Plugin::Foil",
  "recursive_test_files" => 1,
  "requires" => {
    "Config::Context" => 0,
    "File::Serialize" => 0,
    "File::ShareDir" => 0,
    "File::Slurper" => 0,
    "HTML::LinkList" => 0,
    "Image::Size" => 0,
    "Mojo::Base" => 0,
    "Path::Tiny" => 0,
    "common::sense" => 0
  },
  "share_dir" => {
    "dist" => "foil"
  },
  "test_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::More" => 0,
    "blib" => "1.01",
    "perl" => "5.006",
    "strict" => 0,
    "warnings" => 0
  }
);


my %fallback_build_requires = (
  "ExtUtils::MakeMaker" => 0,
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.3601",
  "Test::More" => 0,
  "blib" => "1.01",
  "perl" => "5.006",
  "strict" => 0,
  "warnings" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
