/* ================================================================== */
/* THEME: Cloud
 */
/* ================================================================== */
/* THEME: Cloud - fonts
 */
/* ------------------------------------------------------------------ */
/* Fonts */
h1, h2, h3, h4 {
  font-family: merlin, hancock, black, barcool, "lucida calligraphy", Merced, sans-serif;
  color: black;
}

/* ================================================================== */
/* ICONS - dark on light
 * Nav arrows with transparent backgrounds
 */
.side nav li > ul {
  list-style-image: url(nav_black.png);
}

/* ================================================================== */
/* General */
.verge, header,
footer,
.side, .fancy {
  color: #001133;
  background: #8ca6d9;
  border-color: navy;
  border-radius: 1em;
  border-width: 2px;
}

header,
footer,
.side {
  background-image: url(cloud_h.jpg);
}

body {
  color: #001133;
  background-color: #8ca6d9;
  background-image: url(cloud_main.jpg);
}

a:link {
  color: #005566;
}

a:visited {
  color: #110066;
}

.fancy {
  color: #001133;
  background-image: url("cloud_h.jpg");
  border: 5px double #3366cc;
  padding: 0;
}
.fancy li {
  padding: 0.5em;
  margin: 5px;
  border: 5px solid #3366cc;
  background-color: #8ca6d9;
  background: linear-gradient(#8ca6d9, #5396c6);
}
.fancy li a:link {
  color: #005566;
}
.fancy li a:visited {
  color: #110066;
}

.button, input[type=submit], header nav a,
header nav .selflink,
header nav em,
header nav .current a {
  color: #005566;
  border-color: navy;
  background-color: #6688cc;
}

.button a:link, input[type=submit] a:link, header nav a a:link,
header nav .selflink a:link,
header nav em a:link,
header nav .current a a:link, a.button:link, header nav a:link {
  color: #005566;
}

.button a:visited, input[type=submit] a:visited, header nav a a:visited,
header nav .selflink a:visited,
header nav em a:visited,
header nav .current a a:visited, a.button:visited, header nav a:visited {
  color: #110066;
}

header nav li {
  border-color: #555588;
}

header nav .selflink,
header nav em,
header nav .current a {
  color: navy;
}
