/* ================================================================== */
/* THEME: Rainbow
 */
/* ================================================================== */
/* THEME: Rainbow - fonts
 */
/* ------------------------------------------------------------------ */
/* Fonts */
h1, h2 {
  font-family: Dauphin, 'zaph chancery', ZurichCalligraphic, verdana, sans-serif;
  font-weight: normal;
  color: black;
}

h3, h4 {
  font-family: verdana, helvetica, arial, sans-serif;
  color: black;
}

/* ================================================================== */
/* ICONS - dark on light
 * Nav arrows with transparent backgrounds
 */
.side nav li > ul {
  list-style-image: url(nav_black.png);
}

/* ================================================================== */
/* General */
.verge, header,
footer, .side, .fancy {
  color: #333300;
  background: #ffffcc;
  border-color: #005500;
}

header,
footer {
  background-image: url(rainb1.jpg);
}

.side {
  background: #d5caf2 url(rainb2.jpg);
}

body {
  color: #0e0033;
  background: #d5caf2;
}

a:link {
  color: #001766;
}

a:visited {
  color: #4f0066;
}

.fancy {
  color: #333300;
  background-image: url("rainb2.jpg");
  border: 5px double #ffff66;
  padding: 0;
}
.fancy li {
  padding: 0.5em;
  margin: 5px;
  border: 5px solid #ffff66;
  background-color: #ffffcc;
  background: linear-gradient(#ffffcc, #ffdf80);
}
.fancy li a:link {
  color: #1a3300;
}
.fancy li a:visited {
  color: #663300;
}

.button, input[type=submit], header nav a,
header nav .selflink,
header nav em,
header nav .current a {
  color: #170033;
  border-color: navy;
  background-color: #c0a1e8;
}

.button a:link, input[type=submit] a:link, header nav a a:link,
header nav .selflink a:link,
header nav em a:link,
header nav .current a a:link, a.button:link, header nav a:link {
  color: #170033;
}

.button a:visited, input[type=submit] a:visited, header nav a a:visited,
header nav .selflink a:visited,
header nav em a:visited,
header nav .current a a:visited, a.button:visited, header nav a:visited {
  color: #600066;
}

/* ------------------------------------*/
/* MENUS: navbar */
header nav li {
  border-color: #555588;
}

header nav .selflink,
header nav em,
header nav .current a {
  color: #660066;
  background-color: #d9ffd9;
}
