/* ================================================================== */
/* ICONS - light on dark
 * Nav arrows with transparent backgrounds
 */

.side nav li>ul {
        list-style-image: url(nav_white.png);
}

