/* ================================================================== */
/* ICONS - dark on light
 * Nav arrows with transparent backgrounds
 */

.side nav li>ul {
        list-style-image: url(nav_black.png);
}

