/* ================================================================== */
/* THEME: Green2
 * dark_on_light
 */
/* ================================================================== */
/* THEME: Green
 */
/* ================================================================== */
/* THEME: Green - fonts
 */
/* ------------------------------------------------------------------ */
/* Fonts */
h1, h2, h3, h4 {
  font-family: Merced, "Lucida Calligraphy", "Black", ZurichCalligraphic, verdana, helvetica, arial, sans-serif;
  font-weight: normal;
  color: black;
}

/* ================================================================== */
/* ICONS - dark on light
 * Nav arrows with transparent backgrounds
 */
.side nav li > ul {
  list-style-image: url(nav_black.png);
}

/* ================================================================== */
/* General */
.verge, header,
footer,
.side, .fancy {
  color: #e0ebe0;
  background: #33aa33;
  border-color: #005500;
}

header,
footer,
.side {
  background-image: url(green1a.jpg);
}

body {
  color: #003300;
  background: #66cc66;
}

a:link {
  color: #006633;
}

a:visited {
  color: #1a3300;
}

header a:link,
footer a:link,
.side a:link,
.verge a:link,
header a:link,
footer a:link,
.side a:link,
.fancy a:link {
  color: #a3f5cc;
}

header a:visited,
footer a:visited,
.side a:visited,
.verge a:visited,
header a:visited,
footer a:visited,
.side a:visited,
.fancy a:visited {
  color: #b3f76e;
}

.fancy {
  color: #e0ebe0;
  background-image: url("green1a.jpg");
  border: 5px double #6bbe6b;
  padding: 0;
}
.fancy li {
  padding: 0.5em;
  margin: 5px;
  border: 5px solid #6bbe6b;
  background-color: #33aa33;
  background: linear-gradient(#33aa33, #356f21);
}
.fancy li a:link {
  color: #a3f5cc;
}
.fancy li a:visited {
  color: #b3f76e;
}

.button, input[type=submit], header nav a,
header nav .selflink,
header nav em,
header nav .current a {
  color: #e0ebe0;
  border-color: #003300;
  background-color: #33aa33;
}

.button a:link, input[type=submit] a:link, header nav a a:link,
header nav .selflink a:link,
header nav em a:link,
header nav .current a a:link, a.button:link, header nav a:link {
  color: #e0ebe0;
}

.button a:visited, input[type=submit] a:visited, header nav a a:visited,
header nav .selflink a:visited,
header nav em a:visited,
header nav .current a a:visited, a.button:visited, header nav a:visited {
  color: #b3f76e;
}

header nav li {
  border-color: #116611;
}

header nav .selflink,
header nav em,
header nav .current a {
  background-color: #66cc66;
  color: #003333;
}

/* ================================================================== */
/* THEME: Green2 - fonts
 *
 * This only defines fonts, colours and borders, not layout.
 */
/* ================================================================== */
/* THEME: Green - fonts
 */
/* ------------------------------------------------------------------ */
/* Fonts */
h1, h2, h3, h4 {
  font-family: Merced, "Lucida Calligraphy", "Black", ZurichCalligraphic, verdana, helvetica, arial, sans-serif;
  font-weight: normal;
  color: black;
}

/* ================================================================== */
/* General */
.verge, header,
footer,
.side, .fancy {
  color: #e0ebe0;
  background: #229922;
  border-color: #005500;
}

header,
footer {
  background-image: url(green2_h.jpg);
}

.side {
  background-image: url(green2_side.jpg);
}

a:link {
  color: #006633;
}

a:visited {
  color: #1a3300;
}

header a:link,
footer a:link,
.side a:link,
.verge a:link,
header a:link,
footer a:link,
.side a:link,
.fancy a:link {
  color: #a3f5cc;
}

header a:visited,
footer a:visited,
.side a:visited,
.verge a:visited,
header a:visited,
footer a:visited,
.side a:visited,
.fancy a:visited {
  color: #b3f76e;
}

.fancy {
  color: #e0ebe0;
  background-image: url("green2_h.jpg");
  border: 5px double #48c048;
  padding: 0;
}
.fancy li {
  padding: 0.5em;
  margin: 5px;
  border: 5px solid #48c048;
  background-color: #229922;
  background: linear-gradient(#229922, #265a14);
}
.fancy li a:link {
  color: #a3f5cc;
}
.fancy li a:visited {
  color: #b3f76e;
}

.button, input[type=submit], header nav a,
header nav .selflink,
header nav em,
header nav .current a {
  color: #e0ebe0;
  border-color: #003300;
  background-color: #196f19;
}

.button a:link, input[type=submit] a:link, header nav a a:link,
header nav .selflink a:link,
header nav em a:link,
header nav .current a a:link, a.button:link, header nav a:link {
  color: #e0ebe0;
}

.button a:visited, input[type=submit] a:visited, header nav a a:visited,
header nav .selflink a:visited,
header nav em a:visited,
header nav .current a a:visited, a.button:visited, header nav a:visited {
  color: #b3f76e;
}

header nav li {
  border-color: #116611;
}

header nav .selflink,
header nav em,
header nav .current a {
  background-color: #66cc66;
  color: #003333;
}
