/* ================================================================== */
/* THEME: Turkwoise
 */
@import 'functions';
@import 'fonts_turk';
@import 'icon_light_on_dark';

// -------------------------------------------------------------------
// VARIABLES

$verge-bg: hsl(200, 50%, 60%);
$verge-fg: set-fg($verge-bg);
$verge-border: navy;
$button-bg: darken($verge-bg, 20);
$button-fg: set-fg($button-bg);
$button-visited: set-visited($button-bg);
$button-border: #006666;
$main-bg: #aaaadd;
$main-fg: set-fg($main-bg);
$link-fg: set-link($main-bg);
$link-visited: set-visited($main-bg);
$verge-link-fg: set-link($verge-bg);
$verge-link-visited: set-visited($verge-bg);

/* ================================================================== */
/* General */
.verge {
    color: $verge-fg;
    background: $verge-bg;
    border-color: $verge-border;
}

header,
footer {
	@extend .verge;
	background-image: url(turk1.jpg);
}

.side {
	@extend .verge;
	background-image: url(turk2.jpg);
}

body {
	color: $main-fg;
	background: $main-bg;
}

@include many-links($link-fg, $link-visited, $verge-link-fg, $verge-link-visited);
@include fancy($verge-fg, $verge-bg, "turk2.jpg");
@include make-buttons;

header nav a:visited {
    color: $button-visited;
}
header nav li {
	border-color: #006666;
}
header nav .selflink,
header nav em,
header nav .current a {
	background-color: #aaaadd;
	color: #660000;
}
