/* ================================================================== */
/* THEME: Bronze
 * bronze-ish background, black text
 *
 * This only defines fonts, colours and borders, not layout.
 */
@import 'functions';
@import 'fonts_bronze';
@import 'icon_light_on_dark';

// -------------------------------------------------------------------
// VARIABLES

$verge-bg: #b5631f;
$verge-fg: set-fg($verge-bg);
$verge-border: #552200;
$button-bg: darken($verge-bg, 10%);
$button-fg: set-link($button-bg);
$button-border: $verge-border;
$main-bg: #ffcc55;
$main-fg: set-fg($main-bg);
$link-fg: set-link($main-bg);
$link-visited: set-visited($main-bg);
$verge-link-fg: set-link($verge-bg);
$verge-link-visited: set-visited($verge-bg);

/* ================================================================== */
/* General */
.verge {
    color: $verge-fg;
    background: $verge-bg;
    border-color: $verge-border;
}

header,
footer {
    @extend .verge;
    background-image: url(bronze_h.png);
}

.side {
    @extend .verge;
    background-image: url(bronze_side.png);
}

body {
	color: $main-fg;
	background: $main-bg;
}

@include many-links($link-fg, $link-visited, $verge-link-fg, $verge-link-visited);
@include fancy($verge-fg, $verge-bg, "wood3.jpg");
@include make-buttons;

header nav li {
	border-color: #226622;
}
header nav .selflink,
header nav em,
header nav .current a {
	color: #bb0055;
	background-color: #669933;
}

