/* ================================================================== */
/* THEME: Green3
 */
/* ================================================================== */
/* THEME: Green3 - fonts
 */
/* ------------------------------------------------------------------ */
/* Fonts */
h1, h2 {
  font-family: rudelsberg, fantaisieartistique, forte, castanet, altamontenf, sans-serif;
  color: black;
}

h3, h4 {
  font-family: "aerolite bold", blueplatespecialsw, aduren, sans-serif;
  color: black;
}

/* ================================================================== */
/* ICONS - light on dark
 * Nav arrows with transparent backgrounds
 */
.side nav li > ul {
  list-style-image: url(nav_white.png);
}

/* ================================================================== */
/* General */
.verge, header,
footer, .side, .fancy {
  color: #e2ebe0;
  background: #47853e;
  border-color: #005500;
}

header,
footer {
  background-image: url(green3h.jpg);
}

.side {
  background-image: url(green3.jpg);
}

body {
  color: #063300;
  background: #8ccb83;
}

a:link {
  color: #006626;
}

a:visited {
  color: #203300;
}

header a:link,
footer a:link,
.side a:link,
.verge a:link,
header a:link,
footer a:link,
.side a:link,
.fancy a:link {
  color: #a3f5c2;
}

header a:visited,
footer a:visited,
.side a:visited,
.verge a:visited,
header a:visited,
footer a:visited,
.side a:visited,
.fancy a:visited {
  color: #c4f76e;
}

.fancy {
  color: #e2ebe0;
  background-image: url("green3.jpg");
  border: 5px double #75a16e;
  padding: 0;
}
.fancy li {
  padding: 0.5em;
  margin: 5px;
  border: 5px solid #75a16e;
  background-color: #47853e;
  background: linear-gradient(#47853e, #365126);
}
.fancy li a:link {
  color: #a3f5c2;
}
.fancy li a:visited {
  color: #c4f76e;
}

.button, input[type=submit], header nav a,
header nav .selflink,
header nav em,
header nav .current a {
  color: #e0ebe3;
  border-color: #003300;
  background-color: #3e854d;
}

.button a:link, input[type=submit] a:link, header nav a a:link,
header nav .selflink a:link,
header nav em a:link,
header nav .current a a:link, a.button:link, header nav a:link {
  color: #e0ebe3;
}

.button a:visited, input[type=submit] a:visited, header nav a a:visited,
header nav .selflink a:visited,
header nav em a:visited,
header nav .current a a:visited, a.button:visited, header nav a:visited {
  color: #96f76e;
}

header nav li {
  border-color: #116611;
}

header nav .selflink,
header nav em,
header nav .current a {
  background-color: #66cc66;
  color: #003333;
}

header nav a:visited {
  color: #003333;
}
