/* ================================================================== */
/* THEME: Violet
 */
/* ================================================================== */
/* THEME: Violet - fonts
 */
/* ------------------------------------------------------------------ */
/* Fonts */
h1, h2, h3, h4, h5 {
  font-family: Soucisans, Creedmore, Aduren, Brisk, verdana, helvetica, arial, sans-serif;
  color: black;
}

h6 {
  font-family: verdana, helvetica, arial, sans-serif;
  color: black;
}

/* ================================================================== */
/* ICONS - dark on light
 * Nav arrows with transparent backgrounds
 */
.side nav li > ul {
  list-style-image: url(nav_black.png);
}

/* ================================================================== */
/* General */
.verge, header,
footer, .side, .fancy {
  color: #e5e0eb;
  background: #694b88;
  border-color: #472966;
}

header,
footer {
  background-image: url(vioblue2.jpg);
}

.side {
  background-image: url(vioblue1.jpg);
}

body {
  color: #000033;
  background: #aaaadd;
}

a:link {
  color: #003366;
}

a:visited {
  color: #330066;
}

header a:link,
footer a:link,
.side a:link,
.verge a:link,
header a:link,
footer a:link,
.side a:link,
.fancy a:link {
  color: #a3a4f5;
}

header a:visited,
footer a:visited,
.side a:visited,
.verge a:visited,
header a:visited,
footer a:visited,
.side a:visited,
.fancy a:visited {
  color: #f4a3f5;
}

.fancy {
  color: #e5e0eb;
  background-image: url("vioblue1.jpg");
  border: 5px double #8f809f;
  padding: 0;
}
.fancy li {
  padding: 0.5em;
  margin: 5px;
  border: 5px solid #8f809f;
  background-color: #694b88;
  background: linear-gradient(#694b88, #393057);
}
.fancy li a:link {
  color: #a3a4f5;
}
.fancy li a:visited {
  color: #f4a3f5;
}

.button, input[type=submit], header nav a,
header nav .selflink,
header nav em,
header nav .current a {
  color: #110033;
  border-color: #472966;
  background-color: #967acc;
}

.button a:link, input[type=submit] a:link, header nav a a:link,
header nav .selflink a:link,
header nav em a:link,
header nav .current a a:link, a.button:link, header nav a:link {
  color: #110033;
}

.button a:visited, input[type=submit] a:visited, header nav a a:visited,
header nav .selflink a:visited,
header nav em a:visited,
header nav .current a a:visited, a.button:visited, header nav a:visited {
  color: #560066;
}

header nav a:visited {
  color: #560066;
}

header nav li {
  border-color: #472966;
}

header nav .selflink,
header nav em,
header nav .current a {
  color: black;
  background-color: #aaaadd;
}
