/* ================================================================== */
/* THEME: B7
 * Colours for the "Blake's 7" style
 * pale blue/mauve background, black fore
 *
 * This only defines fonts, colours and borders, not layout.
 */
/* ================================================================== */
/* THEME: B7 - fonts
 */
/* ------------------------------------------------------------------ */
/* Fonts */
h1, h2, h3, h4 {
  font-family: Zekton, Aero, Neuropolitical, Neuropol, Geo, Kimberley, verdana, sans-serif;
  font-weight: normal;
}

/* ================================================================== */
/* ICONS - dark on light
 * Nav arrows with transparent backgrounds
 */
.side nav li > ul {
  list-style-image: url(nav_black.png);
}

/* ================================================================== */
/* General */
.verge, .side,
header,
footer, #main-wrap, .fancy {
  color: #000033;
  background: #aaaadd;
  border-color: navy;
  border-radius: 0;
}

.side,
header,
footer {
  background-image: url(b7_h.jpg);
  background-attachment: fixed;
}

#main-wrap {
  color: #030033;
  background: #cfcdf2;
  border: solid 1px navy;
  box-shadow: rgba(0, 0, 0, 0.8) 3px 3px 10px;
  margin-top: 0.75em;
  margin-bottom: 0.75em;
}

body {
  background-color: #aaaadd;
  background-image: url(b7_body.jpg);
  background-attachment: fixed;
}

a:link {
  color: #002d66;
}

a:visited {
  color: #390066;
}

.fancy {
  color: #000033;
  background-image: url("b7_h.jpg");
  border: 5px double #5656cb;
  padding: 0;
}
.fancy li {
  padding: 0.5em;
  margin: 5px;
  border: 5px solid #5656cb;
  background-color: #aaaadd;
  background: linear-gradient(#aaaadd, #7388c7);
}
.fancy li a:link {
  color: #003366;
}
.fancy li a:visited {
  color: #330066;
}

.button, input[type=submit], header nav a,
header nav .selflink,
header nav em,
header nav .current a {
  color: #003366;
  border-color: navy;
  background-color: #7373c7;
}

.button a:link, input[type=submit] a:link, header nav a a:link,
header nav .selflink a:link,
header nav em a:link,
header nav .current a a:link, a.button:link, header nav a:link {
  color: #003366;
}

.button a:visited, input[type=submit] a:visited, header nav a a:visited,
header nav .selflink a:visited,
header nav em a:visited,
header nav .current a a:visited, a.button:visited, header nav a:visited {
  color: #330066;
}

/* ------------------------------------*/
/* MENUS: navbar */
header nav li {
  border-color: #555588;
}

header nav .selflink,
header nav em,
header nav .current a {
  color: #660066;
  background-color: #cfcdf2;
}
